@@ -11,9 +11,9 @@ A basic wrapper for the Discord API.
 
 """
 
-from encoder.textbytesencoder.textbytesencoder import *
+from textbytesencoder.textbytesencoder import *
 
-__version__ = "1.0.0"
+__version__ = "0.1.4"
 __title__ = 'Encoder'
 __author__ = "D1ffic00lt"
 __copyright__ = "Copyright 2013-2022 {}".format(__author__)
